@@ -1,7 +1,7 @@
 package Git::Bunch;
 
-our $DATE = '2015-01-04'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $DATE = '2015-01-22'; # DATE
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -833,7 +833,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.43 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-01-04.
+This document describes version 0.44 of Git::Bunch (from Perl distribution Git-Bunch), released on 2015-01-22.
 
 =head1 SYNOPSIS
 
@@ -874,7 +874,7 @@ this.
 
 See also L<File::RsyBak>, which I wrote to backup everything else.
 
-=head1 FUNGSI
+=head1 FUNCTIONS
 
 
 =head2 check_bunch(%args) -> [status, msg, result, meta]
@@ -888,7 +888,7 @@ report which repositories are clean/unclean.
 Will die if can't chdir into bunch or git repository.
 }
 
-Argumen ('*' menandakan argumen wajib):
+Arguments ('*' denotes required arguments):
 
 =over 4
 
@@ -930,7 +930,7 @@ and C<exec_bunch> already ignore these and only operate on git repos.
 
 {en_US Only process a single repo}.
 
-=item * B<sort> => I<str> (bawaan: "-commit-timestamp")
+=item * B<sort> => I<str> (default: "-commit-timestamp")
 
 {en_US Order entries in bunch}.
 
@@ -948,16 +948,17 @@ repos more cheaply (compared to doing C<git log -1>).
 
 =back
 
-Mengembalikan hasil terbungkus (larik).
+Returns an enveloped result (an array).
 
-Elemen pertama (status) adalah bilangan bulat berisi kode status HTTP
-(200 berarti OK, 4xx kesalahan di pemanggil, 5xx kesalahan di fungsi). Elemen kedua
-(msg) adalah string berisi pesan kesalahan, atau 'OK' jika status
-200. Elemen ketiga (result) bersifat opsional, berisi hasil yang diinginkan. Elemen keempat
-(meta) disebut metadata hasil, bersifat opsional, berupa hash
-informasi tambahan.
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
 
-Nilai kembali:  (any)
 
 =head2 exec_bunch(%args) -> [status, msg, result, meta]
 
@@ -968,7 +969,7 @@ For each git repository in the bunch, will chdir to it and execute specified
 command.
 }
 
-Argumen ('*' menandakan argumen wajib):
+Arguments ('*' denotes required arguments):
 
 =over 4
 
@@ -1014,7 +1015,7 @@ and C<exec_bunch> already ignore these and only operate on git repos.
 
 {en_US Only process a single repo}.
 
-=item * B<sort> => I<str> (bawaan: "-commit-timestamp")
+=item * B<sort> => I<str> (default: "-commit-timestamp")
 
 {en_US Order entries in bunch}.
 
@@ -1032,16 +1033,17 @@ repos more cheaply (compared to doing C<git log -1>).
 
 =back
 
-Mengembalikan hasil terbungkus (larik).
+Returns an enveloped result (an array).
 
-Elemen pertama (status) adalah bilangan bulat berisi kode status HTTP
-(200 berarti OK, 4xx kesalahan di pemanggil, 5xx kesalahan di fungsi). Elemen kedua
-(msg) adalah string berisi pesan kesalahan, atau 'OK' jika status
-200. Elemen ketiga (result) bersifat opsional, berisi hasil yang diinginkan. Elemen keempat
-(meta) disebut metadata hasil, bersifat opsional, berupa hash
-informasi tambahan.
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
 
-Nilai kembali:  (any)
 
 =head2 sync_bunch(%args) -> [status, msg, result, meta]
 
@@ -1056,7 +1058,7 @@ manually.
 For all other non-git repos, will simply synchronize by one-way rsync.
 }
 
-Argumen ('*' menandakan argumen wajib):
+Arguments ('*' denotes required arguments):
 
 =over 4
 
@@ -1094,7 +1096,7 @@ space-efficient.
 Non-repos will still be copied/rsync-ed.
 }
 
-=item * B<delete_branch> => I<bool> (bawaan: 0)
+=item * B<delete_branch> => I<bool> (default: 0)
 
 {en_US Whether to delete branches in dest repos not existing in source repos}.
 
@@ -1136,7 +1138,7 @@ and C<exec_bunch> already ignore these and only operate on git repos.
 
 {en_US Only process a single repo}.
 
-=item * B<rsync_opt_maintain_ownership> => I<bool> (bawaan: 0)
+=item * B<rsync_opt_maintain_ownership> => I<bool> (default: 0)
 
 {en_US Whether or not, when rsync-ing from source, we use -a (= -rlptgoD) or -rlptD (-a minus -go)}.
 
@@ -1147,7 +1149,7 @@ ownership. If you need to maintain ownership (e.g. you run as root and the repos
 are not owned by root), turn this option on.
 }
 
-=item * B<sort> => I<str> (bawaan: "-commit-timestamp")
+=item * B<sort> => I<str> (default: "-commit-timestamp")
 
 {en_US Order entries in bunch}.
 
@@ -1169,16 +1171,17 @@ repos more cheaply (compared to doing C<git log -1>).
 
 =back
 
-Mengembalikan hasil terbungkus (larik).
+Returns an enveloped result (an array).
 
-Elemen pertama (status) adalah bilangan bulat berisi kode status HTTP
-(200 berarti OK, 4xx kesalahan di pemanggil, 5xx kesalahan di fungsi). Elemen kedua
-(msg) adalah string berisi pesan kesalahan, atau 'OK' jika status
-200. Elemen ketiga (result) bersifat opsional, berisi hasil yang diinginkan. Elemen keempat
-(meta) disebut metadata hasil, bersifat opsional, berupa hash
-informasi tambahan.
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
 
-Nilai kembali:  (any)
 =head1 FAQ
 
 =head1 SEE ALSO
@@ -1200,7 +1203,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Git-Bunch>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Git-Bunch>.
+Source repository is at L<https://github.com/perlancar/perl-Git-Bunch>.
 
 =head1 BUGS
 
